@@ -30,6 +30,13 @@ def main(exit=True, install_tornado_bridge=True, prefer_trollius=True):
 
     application = builder.factory['Application']
     application.setup_signal_handlers()
+
+    if args.debug_manhole:
+        import manhole
+        import wpull
+        wpull.wpull_builder = builder
+        manhole.install()
+
     exit_code = application.run_sync()
 
     if exit:
