@@ -15,4 +15,9 @@ link = {
 	blah2: "http://example.com/http_script_json.html?a\u003db"
 };
 var size = "4.0";
-var mimetype = 'image/png';
\ No newline at end of file
+var mimetype = 'image/png';
+link = "horse dolphin";
+link = "cat[]monkey";
+link = "fish$dog"
+link = "rabbit\\ferre\t"
+link = '\u9'
